Observing Facilities and Observations
=====================================

.. toctree::
  :maxdepth: 2
  :hidden:

  customize_observations
  ../common/scripts
  strategies
  observation_module
  ../api/tom_observations/facilities
  ../api/tom_observations/views


:doc:`Changing Request Submission Behavior <customize_observations>` - Learn how to customize observation forms 
in order to add additional parameters to observation requests.

`Programmatically Submitting Observations <../common/scripts.html#creating-observations-programmatically>`__

:doc:`Cadence and Observing Strategies <strategies>` - Learn how to build cadence strategies that submit observations based on 
the result of prior observations, as well as how to leverage observing templates to submit observations with fewer clicks.

:doc:`Building a TOM Observation Facility Module <observation_module>` - Learn to build a module which will
allow your TOM to submit observation requests to observatories.

:doc:`Facility Modules <../api/tom_observations/facilities>` - Take a look at the supported facilities.

:doc:`Observation Views <../api/tom_observations/views>` - Familiarize yourself with the available Observation Views.
